==> nextcloud-app-news-1:27.2.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/lt_LT.js <==
OC.L10N.register(
    "news",
    {
    "News feeds" : "Naujienų kanalai",
    "Unread articles" : "Neskaityti straipsniai",
    "News" : "Naujienos",
    "News folders" : "Naujienų aplankai",
    "News articles" : "Naujienų straipsniai",
    "An RSS/Atom feed reader" : "RSS/Atom kanalų skaitytuvė",
    "Download" : "Atsisiųsti",
    "Close" : "Užverti",
    "Unknown error!" : "Nežinoma klaida!",
    "Web address" : "Saityno adresas",
    "No folder" : "Be aplanko",
    "Folder name" : "Aplanko pavadinimas",
    "Username" : "Naudotojo vardas",
    "Password" : "Slaptažodis",
    "Feed exists already!" : "Kanalas jau yra!",
    "New folder" : "Naujas aplankas",
    "Folder exists already!" : "Aplankas jau yra!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP Basic Auth prisijungimo duomenys privalo būti laikomi nešifruotu pavidalu! Asmenys, turintys prieigą prie serverio ar duomenų bazės, galės matyti šiuos prisijungimo duomenis!",
    "Credentials" : "Prisijungimo duomenys ",
    "Subscribe" : "Prenumeruoti",
    "Successfully updated news configuration" : "Naujienų konfigūracija sėkmingai atnaujinta",
    "Unable to update news config" : "Nepavyko atnaujinti naujienų konfigūracijos",
    "Last job ran {relativeTime}." : "Paskutinis užduoties vykdymas buvo atliktas {relativeTime}.",
    "Maximum read count per feed" : "Didžiausias kanalo straipsnių kiekis",
    "Maximum redirects" : "Daugiausiai peradresavimų",
    "Feed fetcher timeout" : "Kanalų gavimui skirtas laikas",
    "Explore Service URL" : "Išžvalgymo paslaugos URL",
    "Update interval" : "Atnaujinimo intervalas",
    "Use system cron for updates" : "Atnaujinimams naudoti sistemos planuoklę (cron)",
    "Delete unread articles automatically" : "Automatiškai ištrinti neskaitytus straipsnius",
    "Enable this if you also want to delete unread articles." : "Įjunkite, jei tuo pačiu norite ištrinti neskaitytus straipsnius.",
    "How many redirects the feed fetcher should follow." : "Kiek kartų kanalų gaviklis turėtų sekti paskui peradresavimus.",
    "Article list" : "Straipsnių sąrašas",
    "Article details" : "Išsamiau apie straipsnį",
    "Show all articles" : "Rodyti visus straipsnius",
    "Move" : "Perkelti",
    "User Name" : "Naudotojo vardas",
    "Share" : "Bendrinti",
    "Share with" : "Bendrinti su",
    "Default" : "Numatytasis",
    "Please select a valid OPML file" : "Pasirinkite tinkamą OPML failą",
    "File successfully uploaded" : "Failas įkeltas sėkmingai",
    "Rename Folder" : "Pervadinti aplanką",
    "Are you sure you want to delete?" : "Ar tikrai norite ištrinti?",
    "Mark read" : "Žymėti kaip skaitytą",
    "All articles" : "Visi straipsniai",
    "Starred" : "Pažymėti žvaigždute",
    "Explore" : "Išvalgyti",
    "Settings" : "Nustatymai",
    "Documentation" : "Dokumentacija",
    "Keyboard shortcuts" : "Klavišų kombinacijos",
    "Reverse ordering (oldest on top)" : "Atvirkštinis rikiavimas (seniausi viršuje)",
    "Disable automatic refresh" : "Išjungti automatinį įkėlimą iš naujo",
    "Rename" : "Pervadinti",
    "Delete" : "Ištrinti",
    "Rename Feed" : "Pervadinti kanalą",
    "Open Feed URL" : "Atverti kanalo URL",
    "Unpin from top" : "Atsegti nuo viršaus",
    "Pin to top" : "Prisegti viršuje",
    "Newest first" : "Naujausi pirma",
    "Oldest first" : "Seniausi pirma",
    "Default order" : "Numatytoji tvarka",
    "Enable full text" : "Įjungti raiškųjį tekstą",
    "Disable full text" : "Išjungti raiškųjį tekstą",
    "Previous Item" : "Ankstesnis elementas",
    "Next Item" : "Kitas elementas",
    "Toggle star article" : "Perjungti straipsnio žymėjimą žvaigždute",
    "Mark unread" : "Žymėti kaip neskaitytą",
    "Close details" : "Užverti išsamesnę informaciją",
    "shared by" : "bendrina",
    "by" : " ",
    "Play audio" : "Atkurti garso įrašą",
    "Download audio" : "Atsisiųsti garso įrašą",
    "Download video" : "Atsisiųsti vaizdo įrašą",
    "Open website" : "Atverti svetainę",
    "Keep article unread" : "Palikti straipsnį neskaitytą",
    "Remove keep article unread" : "Nebepalikti straipsnio neskaityto",
    "Please wait" : "Prašome palaukti",
    "Last update" : "Paskutinis atnaujinimas",
    "Next update" : "Kitas atnaujinimas",
    "Title" : "Pavadinimas",
    "Folder" : "Aplankas",
    "Keyboard shortcut" : "Spartusis klavišas",
    "Action" : "Veiksmas",
    "Jump to next article" : "Peršokti į kitą straipsnį",
    "Jump to previous article" : "Peršokti į ankstesnį straipsnį",
    "right" : "dešinė",
    "left" : "kairė",
    "Star article and jump to next one" : "Pažymėti straipsnį ir peršokti prie kito",
    "Open article in new tab" : "Atverti straipsnį naujoje kortelėje",
    "Refresh" : "Įkelti iš naujo",
    "Load next feed" : "Įkelti kitą kanalą",
    "Load previous feed" : "Įkelti ankstesnį kanalą",
    "Load previous folder" : "Įkelti ankstesnį aplanką",
    "Load next folder" : "Įkelti kitą aplanką",
    "Scroll to active navigation entry" : "Slinkti į aktyvų naršymo įrašą",
    "Shift" : "Lyg2",
    "All Articles" : "Visi straipsniai",
    "Subscribe to" : "Prenumeruoti",
    "Unread Articles" : "Neskaityti straipsniai",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Aptikta AJAX ar webcron veiksena! Jūsų kanalai nebus atnaujinti!",
    "How to set up the operating system cron" : "Kaip nusistatyti operacinės sistemos cron",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Įdiekite ir nusistatykite greitesnę lygiagrečią atnaujinimo programą, kuri naudoja Naujienų programėlės atnaujinimo API"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-app-news-1:28.0.0rc.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/lt_LT.js <==
OC.L10N.register(
    "news",
    {
    "News" : "Naujienos",
    "Someone" : "Kažkas",
    "%1$s shared \"%2$s\" with you" : "%1$s pradėjo bendrinti su jumis „%2$s“",
    "News feeds" : "Naujienų kanalai",
    "Unread articles" : "Neskaityti straipsniai",
    "News folders" : "Naujienų aplankai",
    "News articles" : "Naujienų straipsniai",
    "An RSS/Atom feed reader" : "RSS/Atom kanalų skaitytuvė",
    "Download" : "Atsisiųsti",
    "Close" : "Užverti",
    "Unknown error!" : "Nežinoma klaida!",
    "Web address" : "Saityno adresas",
    "No folder" : "Be aplanko",
    "Folder name" : "Aplanko pavadinimas",
    "Username" : "Naudotojo vardas",
    "Password" : "Slaptažodis",
    "Feed exists already!" : "Kanalas jau yra!",
    "New folder" : "Naujas aplankas",
    "Folder exists already!" : "Aplankas jau yra!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP Basic Auth prisijungimo duomenys privalo būti laikomi nešifruotu pavidalu! Asmenys, turintys prieigą prie serverio ar duomenų bazės, galės matyti šiuos prisijungimo duomenis!",
    "Credentials" : "Prisijungimo duomenys ",
    "Subscribe" : "Prenumeruoti",
    "Successfully updated news configuration" : "Naujienų konfigūracija sėkmingai atnaujinta",
    "Unable to update news config" : "Nepavyko atnaujinti naujienų konfigūracijos",
    "Last job ran {relativeTime}." : "Paskutinis užduoties vykdymas buvo atliktas {relativeTime}.",
    "Maximum read count per feed" : "Didžiausias kanalo straipsnių kiekis",
    "Maximum redirects" : "Daugiausiai peradresavimų",
    "Feed fetcher timeout" : "Kanalų gavimui skirtas laikas",
    "Explore Service URL" : "Išžvalgymo paslaugos URL",
    "Update interval" : "Atnaujinimo intervalas",
    "Use system cron for updates" : "Atnaujinimams naudoti sistemos planuoklę (cron)",
    "Delete unread articles automatically" : "Automatiškai ištrinti neskaitytus straipsnius",
    "Enable this if you also want to delete unread articles." : "Įjunkite, jei tuo pačiu norite ištrinti neskaitytus straipsnius.",
    "How many redirects the feed fetcher should follow." : "Kiek kartų kanalų gaviklis turėtų sekti paskui peradresavimus.",
    "Article list" : "Straipsnių sąrašas",
    "Article details" : "Išsamiau apie straipsnį",
    "Show all articles" : "Rodyti visus straipsnius",
    "Move" : "Perkelti",
    "User Name" : "Naudotojo vardas",
    "Share" : "Bendrinti",
    "Share with" : "Bendrinti su",
    "Rename Folder" : "Pervadinti aplanką",
    "Are you sure you want to delete?" : "Ar tikrai norite ištrinti?",
    "Mark read" : "Žymėti kaip skaitytą",
    "All articles" : "Visi straipsniai",
    "Starred" : "Pažymėti žvaigždute",
    "Explore" : "Išvalgyti",
    "Rename" : "Pervadinti",
    "Delete" : "Ištrinti",
    "Rename Feed" : "Pervadinti kanalą",
    "Open Feed URL" : "Atverti kanalo URL",
    "Unpin from top" : "Atsegti nuo viršaus",
    "Pin to top" : "Prisegti viršuje",
    "Newest first" : "Naujausi pirma",
    "Oldest first" : "Seniausi pirma",
    "Default order" : "Numatytoji tvarka",
    "Enable full text" : "Įjungti raiškųjį tekstą",
    "Disable full text" : "Išjungti raiškųjį tekstą",
    "Previous Item" : "Ankstesnis elementas",
    "Next Item" : "Kitas elementas",
    "Toggle star article" : "Perjungti straipsnio žymėjimą žvaigždute",
    "Mark unread" : "Žymėti kaip neskaitytą",
    "Close details" : "Užverti išsamesnę informaciją",
    "shared by" : "bendrina",
    "by" : " ",
    "Play audio" : "Atkurti garso įrašą",
    "Download audio" : "Atsisiųsti garso įrašą",
    "Download video" : "Atsisiųsti vaizdo įrašą",
    "Open website" : "Atverti svetainę",
    "Keep article unread" : "Palikti straipsnį neskaitytą",
    "Remove keep article unread" : "Nebepalikti straipsnio neskaityto",
    "Default" : "Numatytasis",
    "Please select a valid OPML file" : "Pasirinkite tinkamą OPML failą",
    "File successfully uploaded" : "Failas įkeltas sėkmingai",
    "General" : "Bendra",
    "Reverse ordering (oldest on top)" : "Atvirkštinis rikiavimas (seniausi viršuje)",
    "Disable automatic refresh" : "Išjungti automatinį įkėlimą iš naujo",
    "Appearance" : "Išvaizda",
    "Import" : "Importuoti",
    "Export" : "Eksportuoti",
    "Please wait" : "Prašome palaukti",
    "Keyboard shortcuts" : "Klavišų kombinacijos",
    "Refresh" : "Įkelti iš naujo",
    "Jump to previous article" : "Peršokti į ankstesnį straipsnį",
    "Jump to next article" : "Peršokti į kitą straipsnį",
    "Open article in new tab" : "Atverti straipsnį naujoje kortelėje",
    "Resources" : "Ištekliai",
    "Last update" : "Paskutinis atnaujinimas",
    "Next update" : "Kitas atnaujinimas",
    "Title" : "Pavadinimas",
    "Folder" : "Aplankas",
    "All Articles" : "Visi straipsniai",
    "Subscribe to" : "Prenumeruoti",
    "Unread Articles" : "Neskaityti straipsniai",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Aptikta AJAX ar webcron veiksena! Jūsų kanalai nebus atnaujinti!",
    "How to set up the operating system cron" : "Kaip nusistatyti operacinės sistemos cron",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Įdiekite ir nusistatykite greitesnę lygiagrečią atnaujinimo programą, kuri naudoja Naujienų programėlės atnaujinimo API"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
